#-*- mode: Fundamental; tab-width: 4; -*-
# ex:ts=4
# $Id: gar.conf.mk,v 1.29 2003/03/05 02:13:14 jdub Exp $

# This file contains configuration variables that are global to
# the GAR system.  Users wishing to make a change on a
# per-package basis should edit the category/package/Makefile, or
# specify environment variables on the make command-line.

# Variables that define the default *actions* (rather than just
# default data) of the system will remain in bbc.gar.mk
# (bbc.port.mk)

# Setting this variable will cause the results of your builds to
# be cleaned out after being installed.  Uncomment only if you
# desire this behavior!

# export BUILD_CLEAN = true

# The GARCHIVEDIR is a directory containing cached files. It can be created
# manually, or with 'make garchive' once you've started downloading required
# files (say with 'make paranoid-checksum'. Example:

#GARCHIVEDIR = /home/brian/src/xfce4/garxfce4/DOWNLOAD

# Makes the bulk of the read/write work happen elsewhere. I use this
# to make patch generation less taxing.

#WORKROOTDIR = /tmp/garnome-work/$(GARNAME)

# These are the standard directory name variables from all GNU
# makefiles.  They're also used by autoconf, and can be adapted
# for a variety of build systems.
# 
# TODO: set $(SYSCONFDIR) and $(LOCALSTATEDIR) to never use
# /usr/etc or /usr/var

DESTIMG ?= main

# Directory config for the "main" image
main_prefix ?= $(HOME)/garxfce4
main_exec_prefix = $(main_prefix)
main_bindir = $(main_exec_prefix)/bin
main_sbindir = $(main_exec_prefix)/sbin
main_libexecdir = $(main_exec_prefix)/libexec
main_datadir = $(main_prefix)/share
main_sysconfdir = $(main_prefix)/etc
main_sharedstatedir = $(main_prefix)/share
main_localstatedir = $(main_prefix)/var
main_libdir = $(main_exec_prefix)/lib
main_infodir = $(main_prefix)/info
main_lispdir = $(main_prefix)/share/emacs/site-lisp
main_includedir = $(main_prefix)/include
main_mandir = $(main_prefix)/man
main_docdir = $(main_prefix)/share/doc
main_sourcedir = $(main_prefix)/src
main_licensedir = $(main_prefix)/licenses

prefix = $($(DESTIMG)_prefix)
exec_prefix = $($(DESTIMG)_exec_prefix)
bindir = $($(DESTIMG)_bindir)
sbindir = $($(DESTIMG)_sbindir)
libexecdir = $($(DESTIMG)_libexecdir)
datadir = $($(DESTIMG)_datadir)
sysconfdir = $($(DESTIMG)_sysconfdir)
sharedstatedir = $($(DESTIMG)_sharedstatedir)
localstatedir = $($(DESTIMG)_localstatedir)
libdir = $($(DESTIMG)_libdir)
infodir = $($(DESTIMG)_infodir)
lispdir = $($(DESTIMG)_lispdir)
includedir = $($(DESTIMG)_includedir)
mandir = $($(DESTIMG)_mandir)
docdir = $($(DESTIMG)_docdir)
sourcedir = $($(DESTIMG)_sourcedir)
licensedir = $($(DESTIMG)_licensedir)

# the DESTDIR is used at INSTALL TIME ONLY to determine what the
# filesystem root should be.  Each different DESTIMG has its own
# DESTDIR.
main_DESTDIR ?=

DESTDIR = $(main_DESTDIR)

BUILD_PREFIX ?= $(prefix)

# allow us to link to libraries we installed
CPPFLAGS += -I$(DESTDIR)$(includedir) -I$(DESTDIR)/usr/X11R6/include
CFLAGS += -I$(DESTDIR)$(includedir) -I$(DESTDIR)/usr/X11R6/include -L$(DESTDIR)$(libdir) -L$(DESTDIR)/usr/X11R6/lib
LDFLAGS += -L$(DESTDIR)$(libdir) -L$(DESTDIR)/usr/X11R6/lib
# allow us to use programs we just built
PATH := $(DESTDIR)$(bindir):$(DESTDIR)$(sbindir):$(DESTDIR)$(BUILD_PREFIX)/bin:$(DESTDIR)$(BUILD_PREFIX)/sbin:$(PATH)
LD_LIBRARY_PATH := $(DESTDIR)$(libdir):$(DESTDIR)$(BUILD_PREFIX)/lib:$(LD_LIBRARY_PATH)

# This is for foo-config chaos
PKG_CONFIG_PATH=$(DESTDIR)$(libdir)/pkgconfig:/usr/lib/pkgconfig


# Sensible testing defaults
CFLAGS += -O2 -pipe

# Batshit insane optimisations

# Old compiler
#CC = gcc-2.95
#CXX = gcc-2.95
# Intel Pentium Pro and above
#CFLAGS += -march=pentiumpro

# GCC 3.2
#CC = gcc-3.2
#CXX = g++-3.2
# GCC 3.3
#CC = gcc-3.3
#CXX = g++-3.3

# GCC 3.x CFLAGS
# Intel Pentium Pro and above
#CFLAGS += -march=pentiumpro
# My iBook
#CFLAGS += -march=750

# Intel's ICC
#CC = /opt/intel/compiler70/ia32/bin/icc
#CXX = /opt/intel/compiler70/ia32/bin/icc

# ccache, if you've got it - you must set CC and CXX above too!
#CC := ccache $(CC)
#CXX := ccache $(CXX)

# Equalise CFLAGS and CXXFLAGS
CXXFLAGS := $(CFLAGS)

# If you want to use a different version of python everywhere
# change this
PYTHON = $(shell which python)

# Let's see if we can get gtk-doc going 100%
XML_CATALOG_FILES += $(DESTDIR)$(sysconfdir)/xml/catalog

# Put these variables in the environment during the
# configure build and install stages
STAGE_EXPORTS = DESTDIR prefix exec_prefix bindir sbindir libexecdir datadir
STAGE_EXPORTS += sysconfdir sharedstatedir localstatedir libdir infodir lispdir
STAGE_EXPORTS += includedir mandir docdir sourcedir
STAGE_EXPORTS += CPPFLAGS CFLAGS CXXFLAGS LDFLAGS
STAGE_EXPORTS += CC CXX PYTHON

CONFIGURE_ENV += $(foreach TTT,$(STAGE_EXPORTS),$(TTT)="$($(TTT))")
BUILD_ENV += $(foreach TTT,$(STAGE_EXPORTS),$(TTT)="$($(TTT))")
INSTALL_ENV += $(foreach TTT,$(STAGE_EXPORTS),$(TTT)="$($(TTT))")
MANIFEST_ENV += $(foreach TTT,$(STAGE_EXPORTS),$(TTT)="$($(TTT))")

# Global environment
export PATH LD_LIBRARY_PATH #LD_PRELOAD
export PKG_CONFIG_PATH XML_CATALOG_FILES GNOMECVSROOT

# prepend the local file listing
FILE_SITES = file://$(FILEDIR)/ file://$(GARCHIVEDIR)/

# Extra libs to include with gar.mk
#EXTRA_LIBS =
